import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { IUser } from '../../models/user';
import { AppConfig } from '../../shared/app.config';

@Component({
  selector: 'fm-avatar',
  templateUrl: './avatar.component.html',
  styleUrls: ['./avatar.component.css']
})
export class AvatarComponent implements OnInit {

  @Input() user: IUser;
  @Input() bgColor: string;
  @Input() fgColor: string;
  @Input() size: number;
  @Input() round: boolean;

  @Output() click = new EventEmitter();
  
  constructor(private appConfig: AppConfig) {
  }

  ngOnInit(): void {
  }

  getAvatar():string {
    if (!this.user) return null;
    const apiEndpoint = this.appConfig.getConfig("apiEndPoint");
    return `${apiEndpoint}/api/v1/users//${this.user.code}/avatar`;
  }

  getName():string {
    if (!this.user) return null;
    if (this.user.firstName && this.user.lastName)
      return this.user.firstName + ' ' + this.user.lastName;
    return this.user.name;
  }

  onClick() {
    this.click.emit();
  }
}
